==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/en/post.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'back_to_edit_form'=>'Back to Edit Form',
'bbcode_button_anchor'=>'You can set an anchor in your posting and link to it',
'bbcode_button_bold'=>'Select your text and click here to make it bold',
'bbcode_button_code'=>'Select your text and click here to make it be source code',
'bbcode_button_embed'=>'Click here to include an external URL to be embedded (often multimedia)',
'bbcode_button_format'=>'Click here first, select your text and apply special formatting at last',
'bbcode_button_img'=>'Click here to include an external image to be shown directly',
'bbcode_button_italic'=>'Select your text and click here to make it in italics',
'bbcode_button_link'=>'Using this option you can link to another posting in our forum or one of your anchors',
'bbcode_button_mail'=>'Click here to include an e-mail address',
'bbcode_button_notice'=>'Privileged users can emphasize a paragraph by using this tag',
'bbcode_button_quote'=>'Select a text and click here to indicate you quoted someone',
'bbcode_button_strikethrough'=>'Select your text and click here to make it be strikethrough',
'bbcode_button_underline'=>'Select your text and click here to make it be underline',
'bbcode_button_url'=>'Click here to include an external URL',
'cannot_delete_topic_without_executive'=>'You cannot delete a topic without executive permission!',
'cannot_reply_as_topic_is_closed'=>'You cannot reply to an already closed topic!',
'compare_posts'=>'Compare Postings',
'compare_selected_revisions'=>'Compare the selected revisions',
'edited_because'=>'Edited before because',
'edit_posting'=>'Edit Posting',
'explain_message'=>'Your message contains your information. Here you can discuss, reply, ask or do anything else.',
'explain_post_acl'=>'You can assign an access restriction to this topic. Only members matching the rules, can read the topic.',
'explain_post_user'=>'You may change the username of this posting.',
'explain_post_weight'=>'The higher the "weight" of your post, the earlier it is enlisted. Your highest setting is limited by your user group.',
'explain_reason'=>'You can put your reasons here why you edited this posting. Keep it short and descriptive.',
'explain_subject'=>'A subject summarizes your message in a few words. If prefixes are available, you can quickly sort it into one category.',
'explain_tags'=>'You can apply tags to your post to describe it. These are used to group messages sharing a tag and allow easy search for it. Separate multiple tags with comma. For example, if you write about delicious bananas, you could tag it like "banana,delicious,fruit,eating".',
'is_approved_by_default'=>'Posting is approved by default and visible at once.',
'is_hidden_by_default'=>'Posting will require approvement before being visible.',
'listing_all_previous_versions'=>'Here are previous versions of this posting',
'new_reply'=>'New Reply',
'new_reply_successfully_posted'=>'Your reply has been posted to this topic.',
'new_topic'=>'New Topic',
'new_topic_successfully_posted'=>'Your topic has been posted to our forum.',
'not_allowed_to_access_the_topic'=>'You are not allowed to access the topic you want to reply to!',
'not_allowed_to_submit_repeated_posting'=>'You are not allowed to submit another posting as the last is yours!',
'posting_has_been_deleted'=>'This posting has been deleted.',
'posting_has_been_edited'=>'This posting has been edited.',
'post_acl'=>'Access Control',
'post_source'=>'Source Posting',
'post_target'=>'Target Posting',
'post_weight'=>'Weight',
'quote_hint'=>'If you quoted a message, please reduce it to the minimal set.',
'rate_disallowed_by_being_too_quiet'=>'You are not yet allowed to rate a posting because you posted too few topics or replies!',
'rate_disallowed_by_short_membership'=>'You are not yet allowed to rate a posting because your membership is too short!',
'reason'=>'Edit Reason',
'revert_post'=>'Revert to this revision',
'successfully_rate_posting'=>'Your rating of this posting has been registered.',
'time_limit_exceeded_for_edit'=>'You are not allowed to edit this posting as it is too old.',
'version_by'=>'Version by',
'you_cannot_rate_yourself'=>'You cannot rate your own posting!',
'you_cannot_select_this_prefix'=>'You are not allowed to select this post prefix!',
'you_have_already_rated'=>'You have already rated this posting!'
);
?>

==> larus_board-1.1.0.zip: larus_board-1.1.0/lb_private/lang/en/post.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'back_to_edit_form'=>'Back to Edit Form',
'bbcode_button_anchor'=>'You can set an anchor in your posting and link to it',
'bbcode_button_bold'=>'Select your text and click here to make it bold',
'bbcode_button_code'=>'Select your text and click here to make it be source code',
'bbcode_button_embed'=>'Click here to include an external URL to be embedded (often multimedia)',
'bbcode_button_format'=>'Click here first, select your text and apply special formatting at last',
'bbcode_button_img'=>'Click here to include an external image to be shown directly',
'bbcode_button_italic'=>'Select your text and click here to make it in italics',
'bbcode_button_link'=>'Using this option you can link to another posting in our forum or one of your anchors',
'bbcode_button_mail'=>'Click here to include an e-mail address',
'bbcode_button_notice'=>'Privileged users can emphasize a paragraph by using this tag',
'bbcode_button_quote'=>'Select a text and click here to indicate you quoted someone',
'bbcode_button_strikethrough'=>'Select your text and click here to make it be strikethrough',
'bbcode_button_underline'=>'Select your text and click here to make it be underline',
'bbcode_button_url'=>'Click here to include an external URL',
'cannot_reply_as_topic_is_closed'=>'You cannot reply to an already closed topic!',
'compare_posts'=>'Compare Postings',
'compare_selected_revisions'=>'Compare the selected revisions',
'current_revision'=>'Current Revision',
'edited_because'=>'Edited before because',
'edit_posting'=>'Edit Posting',
'explain_message'=>'Your message contains your information. Here you can discuss, reply, ask or do anything else.',
'explain_post_acl'=>'You can assign an access restriction to this topic. Only members matching the rules, can read the topic.',
'explain_post_user'=>'You may change the username of this posting.',
'explain_post_weight'=>'The higher the "weight" of your post, the earlier it is enlisted. Your highest setting is limited by your user group.',
'explain_reason'=>'You can put your reasons here why you edited this posting. Keep it short and descriptive.',
'explain_subject'=>'A subject summarizes your message in a few words. If prefixes are available, you can quickly sort it into one category.',
'explain_tags'=>'You can apply tags to your post to describe it. These are used to group messages sharing a tag and allow easy search for it. Separate multiple tags with comma. For example, if you write about delicious bananas, you could tag it like "banana,delicious,fruit,eating".',
'is_approved_by_default'=>'Posting is approved by default and visible at once.',
'is_hidden_by_default'=>'Posting will require approvement before being visible.',
'listing_all_previous_versions'=>'Here are previous versions of this posting',
'new_reply'=>'New Reply',
'new_reply_successfully_posted'=>'Your reply has been posted to this topic.',
'new_topic'=>'New Topic',
'new_topic_successfully_posted'=>'Your topic has been posted to our forum.',
'not_allowed_to_access_the_topic'=>'You are not allowed to access the topic you want to reply to!',
'not_allowed_to_submit_repeated_posting'=>'You are not allowed to submit another posting as the last is yours!',
'posting_has_been_deleted'=>'This posting has been deleted.',
'posting_has_been_edited'=>'This posting has been edited.',
'post_acl'=>'Access Control',
'post_source'=>'Source Posting',
'post_target'=>'Target Posting',
'post_weight'=>'Weight',
'quote_hint'=>'If you quoted a message, please reduce it to the minimal set.',
'rate_disallowed_by_being_too_quiet'=>'You are not yet allowed to rate a posting because you posted too few topics or replies!',
'rate_disallowed_by_short_membership'=>'You are not yet allowed to rate a posting because your membership is too short!',
'reason'=>'Edit Reason',
'revert_post'=>'Revert to this revision',
'successfully_rate_posting'=>'Your rating of this posting has been registered.',
'time_limit_exceeded_for_edit'=>'You are not allowed to edit this posting as it is too old.',
'version_by'=>'Version by',
'your_posting_has_been_filtered_as_spam'=>'Your message has been marked as unwanted ("spam") by our filtering system.',
'you_cannot_rate_yourself'=>'You cannot rate your own posting!',
'you_cannot_select_this_prefix'=>'You are not allowed to select this post prefix!',
'you_have_already_rated'=>'You have already rated this posting!'
);
?>
